@@ -54,7 +54,7 @@ class NxPyDocs():
                 command_output = clid( '%s' % self.command )
                 parsed_json = json.loads(command_output)
                 if self.filetype:
-                    if self.repo:
+                    if self.repo != "none":
                         self.clone()
                         self.pick_filetype(parsed_json)
                         self.send_to_repo()
@@ -66,7 +66,7 @@ class NxPyDocs():
                 command_output = clid( '%s' % self.command )
                 parsed_json = json.loads(command_output)
                 if self.filetype:
-                    if self.repo:
+                    if self.repo != "none":
                         self.clone()
                         self.pick_filetype(parsed_json)
                         self.send_to_repo()
@@ -76,8 +76,10 @@ class NxPyDocs():
                 else:
                     click.secho(json.dumps(parsed_json,indent=4, sort_keys=True))
             else:
-                click.secho("Show Command Not Yet Templated", fg='red')
-
+                command_output = clid( '%s' % self.command )
+                parsed_json = json.loads(command_output)
+                click.secho(json.dumps(parsed_json,indent=4, sort_keys=True))
+                
     def pick_filetype(self, parsed_json):
         if self.filetype == "none":
             pass
@@ -201,15 +203,15 @@ class NxPyDocs():
 @click.option('--repo',
     prompt='Git Repository',
     help=('The Git repository to send the output files'),
-    required=False,envvar="REPO")
+    required=False,envvar="REPO",default='none')
 @click.option('--username',
     prompt='Git Repository Username',
     help=('The Git repository username'),
-    required=False,envvar="USERNAME")
+    required=False,envvar="USERNAME",default='none')
 @click.option('--token',
     prompt='Git Repository token',
     help=('The Git repository token'),
-    required=False,hide_input=True,envvar="TOKEN")    
+    required=False,hide_input=True,envvar="TOKEN",default='none')
 def cli(command,
         filetype,
         repo,
